@@ -187,8 +187,11 @@ help_cb (BonoboUIComponent   *uic,
 		&error);
 
 	if (error) { 
+		GtkWidget *parent =
+			gtk_widget_get_parent (GTK_WIDGET (sapplet->applet));
+
 		GtkWidget *dialog = 
-			gtk_message_dialog_new (GTK_WINDOW (sapplet->applet),
+			gtk_message_dialog_new (GTK_WINDOW (parent),
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR,
 						GTK_BUTTONS_CLOSE,
@@ -1024,7 +1027,7 @@ popup_error_dialog (AccessxStatusApplet* sapplet)
 
 	switch (sapplet->error_type) {
 		case ACCESSX_STATUS_ERROR_XKB_DISABLED : 
-			error_txt = g_strdup (_("XKB Extenstion is not enabled"));
+			error_txt = g_strdup (_("XKB Extension is not enabled"));
 			break;
 
 		case ACCESSX_STATUS_ERROR_UNKNOWN :
