@@ -1,7 +1,7 @@
 #ifndef __WEATHER_H_
 #define __WEATHER_H_
 
-/* $Id: weather.h,v 1.20 2004/01/25 14:45:55 jamesh Exp $ */
+/* $Id: weather.h,v 1.26 2004/11/29 03:48:21 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -28,15 +28,22 @@ G_BEGIN_DECLS
 #define WEATHER_LOCATION_CODE_LEN 4
 
 struct _WeatherLocation {
-    gchar *name;
+    gchar *untrans_name;
+    gchar *trans_name;
     gchar *code;
     gchar *zone;
     gchar *radar;
+    gboolean zone_valid;
+    gchar *coordinates;
+    gdouble  latitude;
+    gdouble  longitude;
+    gboolean latlon_valid;
 };
 
 
 
-extern WeatherLocation *weather_location_new (const gchar *name, const gchar *code, const gchar *zone, const gchar *radar);
+extern WeatherLocation *weather_location_new (const gchar *untrans_name, const gchar *trans_name, const gchar *code,
+					      const gchar *zone, const gchar *radar, const gchar *coordinates);
 extern WeatherLocation *weather_location_clone (const WeatherLocation *location);
 extern void weather_location_free (WeatherLocation *location);
 extern gboolean weather_location_equal (const WeatherLocation *location1, const WeatherLocation *location2);
@@ -135,13 +142,6 @@ typedef struct _WeatherConditions WeatherConditions;
 
 extern const gchar *weather_conditions_string (WeatherConditions cond);
 
-enum _WeatherUnits {
-    UNITS_IMPERIAL,
-    UNITS_METRIC
-};
-
-typedef enum _WeatherUnits WeatherUnits;
-
 enum _WeatherForecastType {
     FORECAST_STATE,
     FORECAST_ZONE
@@ -150,13 +150,11 @@ enum _WeatherForecastType {
 typedef enum _WeatherForecastType WeatherForecastType;
 
 typedef gdouble WeatherTemperature;
-typedef gint WeatherHumidity;
+typedef gdouble WeatherHumidity;
 typedef gint WeatherWindSpeed;
 typedef gdouble WeatherPressure;
 typedef gdouble WeatherVisibility;
 
-extern void weather_units_set (WeatherUnits units);
-extern WeatherUnits weather_units_get (void);
 
 extern void weather_forecast_set (WeatherForecastType forecast);
 extern WeatherForecastType weather_forecast_get (void);
@@ -170,18 +168,19 @@ typedef time_t WeatherUpdate;
 
 struct _WeatherInfo {
     gboolean valid;
+    gboolean sunValid;
     WeatherLocation *location;
-    WeatherUnits units;
     WeatherUpdate update;
     WeatherSky sky;
     WeatherConditions cond;
     WeatherTemperature temp;
     WeatherTemperature dew;
-    WeatherHumidity humidity;
     WeatherWindDirection wind;
     WeatherWindSpeed windspeed;
     WeatherPressure pressure;
     WeatherVisibility visibility;
+    WeatherUpdate sunrise;
+    WeatherUpdate sunset;
     gchar *forecast;
     gchar *metar_buffer;
     gchar *iwin_buffer;
@@ -191,6 +190,7 @@ struct _WeatherInfo {
     gchar *radar_url;
     GdkPixbufLoader *radar_loader;
     GdkPixmap *radar;
+    GdkBitmap *radar_mask;
     GnomeVFSAsyncHandle *metar_handle;
     GnomeVFSAsyncHandle *iwin_handle;
     GnomeVFSAsyncHandle *wx_handle;
@@ -226,6 +226,9 @@ extern const gchar *weather_info_get_humidity (WeatherInfo *info);
 extern const gchar *weather_info_get_wind (WeatherInfo *info);
 extern const gchar *weather_info_get_pressure (WeatherInfo *info);
 extern const gchar *weather_info_get_visibility (WeatherInfo *info);
+extern const gchar *weather_info_get_apparent (WeatherInfo *info);
+extern const gchar *weather_info_get_sunrise(WeatherInfo *info);
+extern const gchar *weather_info_get_sunset(WeatherInfo *info);
 extern const gchar *weather_info_get_forecast (WeatherInfo *info);
 extern GdkPixmap *weather_info_get_radar (WeatherInfo *info);
 
@@ -234,7 +237,6 @@ extern gchar *weather_info_get_weather_summary (WeatherInfo *info);
 
 extern void update_finish (WeatherInfo *info);
 
-extern time_t make_time (gint date, gint hour, gint min);
 
 extern void _weather_info_get_pixbuf (WeatherInfo *info, gboolean mini, GdkPixbuf **pixbuf);
 #define weather_info_get_pixbuf_mini(info,pixbuf) _weather_info_get_pixbuf((info), TRUE, (pixbuf))
@@ -243,4 +245,3 @@ extern void _weather_info_get_pixbuf (WeatherInfo *info, gboolean mini, GdkPixbu
 G_END_DECLS
 
 #endif /* __WEATHER_H_ */
-
